pub struct UseCase {
pub mandatory: bool,
pub document_sets: NonEmptyVec<DocumentSet>,
pub purpose_hints: Option<PurposeHints>,
}Expand description
Represents a use case.
Fields
mandatory: boolWhether this use case is required.
document_sets: NonEmptyVec<DocumentSet>Document requests that must comply with this use case.
purpose_hints: Option<PurposeHints>Option hints to help the user distinguish between use cases.