RequestAuthenticationOutcome

Struct RequestAuthenticationOutcome 

pub struct RequestAuthenticationOutcome {
    pub items_request: RequestedItems,
    pub common_name: Option<String>,
    pub reader_authentication: AuthenticationStatus,
    pub errors: Errors,
}
The outcome of the holder device authenticating the device request.

Fields

items_request: RequestedItems

The requested items from the mDL namespace.

common_name: Option<String>

The common name from the certificate that signed this request, if available. This value can be used to display to the user who the reader is, however caution should be exercised if reader authentication was not successful.

reader_authentication: AuthenticationStatus

Outcome of reader authentication.

errors: Errors

Errors that occurred during request processing.